Dojo Slider Widget Demo

# Slider

Also try using the arrow keys, buttons, or clicking on the progress bar to move the slider.
initial value=10, min=0, max=100, pageIncrement=100, onChange event triggers input box value change immediately
Horizontal Slider Example, "rtl" base text direction

1. תגlowest!
2. תגnormal!
3. תגhighest!

Slider1 Value:
initial value=10, min=0, max=100, onChange event triggers input box value change when you mouse up or tab away

# Fancy HTML labels (no slide animation), "rtl" base text direction:

1. תגsmall!
2. תגmedium!
3. תגlarge!

## Completely programmatic VerticalSlider and VerticalRule, "auto" base text direction

### min:1000, max:3000, 11 discrete values, no animation

Programmatic Value:
Errors: ?
Failures: ?